package com.zhyc.module.biosafety.service;

import java.util.List;
import com.zhyc.module.biosafety.domain.SwDisease;

/**
 * 疾病Service接口
 * 
 * @author ruoyi
 * @date 2025-07-09
 */
public interface ISwDiseaseService 
{
    /**
     * 查询疾病
     * 
     * @param id 疾病主键
     * @return 疾病
     */
    public SwDisease selectSwDiseaseById(Long id);

    /**
     * 查询疾病列表
     * 
     * @param swDisease 疾病
     * @return 疾病集合
     */
    public List<SwDisease> selectSwDiseaseList(SwDisease swDisease);

    /**
     * 新增疾病
     * 
     * @param swDisease 疾病
     * @return 结果
     */
    public int insertSwDisease(SwDisease swDisease);

    /**
     * 修改疾病
     * 
     * @param swDisease 疾病
     * @return 结果
     */
    public int updateSwDisease(SwDisease swDisease);

    /**
     * 批量删除疾病
     * 
     * @param ids 需要删除的疾病主键集合
     * @return 结果
     */
    public int deleteSwDiseaseByIds(Long[] ids);

    /**
     * 删除疾病信息
     * 
     * @param id 疾病主键
     * @return 结果
     */
    public int deleteSwDiseaseById(Long id);
}
